@@ -109,6 +109,11 @@ def findmnt(options, path=None):
         return None
 
 
+def unmount(path):
+    umount = ExternalBinary().umount
+    return umount([path])
+
+
 def find_mount_target():
     return findmnt(["TARGET", "-l"]).split()
 
@@ -144,7 +149,11 @@ def call(*args, **kwargs):
     if "stderr" not in kwargs:
         kwargs["stderr"] = subprocess.STDOUT
     log.debug("Calling: %s %s" % (args, kwargs))
-    return subprocess.check_output(*args, **kwargs).strip()
+    try:
+        return subprocess.check_output(*args, **kwargs).strip()
+    except subprocess.CalledProcessError as e:
+        log.debug("Exception! %s" % e.output)
+        raise
 
 
 def format_to_pattern(fmt):
@@ -244,6 +253,7 @@ def bindmounted(source, target, rbind=False):
     options = "rbind,rprivate" if rbind else "bind,private"
     with mounted(source, target=target, options=options) as mnt:
         yield mnt
+    log.debug("Done!")
 
 
 def sorted_versions(versions, delim="."):
@@ -322,7 +332,7 @@ class Filesystem():
 class Ext4(Filesystem):
     @staticmethod
     def mkfs(path, debug=False):
-        cmd = ["mkfs.ext4", "-c", "-E", "discard", path]
+        cmd = ["mkfs.ext4", "-E", "discard", path]
         if not debug:
             cmd.append("-q")
         log.debug("Running: %s" % cmd)
@@ -459,6 +469,7 @@ class LvmCLI():
     lvextend = LvmBinary().lvextend
     vgcreate = LvmBinary().vgcreate
     vgchange = LvmBinary().vgchange
+    lvmconfig = LvmBinary().lvmconfig
 
 
 class SELinuxDomain(object):
@@ -972,7 +983,7 @@ class Rsync():
         call(cmd)
 
     def sync(self, sourcetree, dst):
-        assert os.path.isdir(sourcetree), "%s is not a directory" % sourcetree
+        assert os.path.isdir(sourcetree)
 
         cmd = ["rsync"]
         cmd += ["-pogAXlHrx"]
@@ -1599,3 +1610,4 @@ class ExitStack(object):
                     raise
                 exc_details = new_exc_details
         return suppressed_exc
+# vim: sw=4 et sts=4
